% plot 3-dimensional frame
% function [] = Plot3DFrame(D)
%
% This algorithm plots a 3-dimensional frame resp. any sequence of column 
% vectors as vector arrows. 
%  
% inputs : D ......... Matrix containing the column vectors to be plotted.
%
% usage:  Plot3DFrame(D)
%
% test:   M = 5;
%         dim = 3;
%         D = rand(5,3);
%         Plot3DFrame(D);
%
% date: 27/06/2006 
%
% external: this algorithm uses 'vectarrow', 
%           'Plot 2D/3D Vector with Arrow' by Rentian Xiong 
%           http://www.mathworks.com/matlabcentral/fileexchange/loadFile.do?objectId=7470&objectType=file
%
% Author:  XXL .. Peter Balazs, contact: a8927259@unet.univie.ac.at
%
% Literature : [Xxl] P. Balazs; Frames, Finite Dimensionality and
%               Algorithms; in preparation (2006)
%
% See also: RandFrame.m
%
function Plot3DFrame(D)

[N M] = size(D);
if N ~= 3
    if M == 3
        D = D.';
        N = 3;
    else
        disp('This function only works for 3-dimensional vectors.');
        return
    end
end

vectarrow(zeros(3,1),D(:,1));
for ii = 2: M 
    hold on;
    vectarrow(zeros(3,1),D(:,ii));
end
mmm = max(max(abs(D)));
axis([-mmm mmm -mmm mmm -mmm mmm]);
