% Create random frame (in the unit circle).
% function D = RandFrame(dim,M)
%
% This simple algorithm creates a random frame with elements of length <= 1.
% For 2-dimensional frames the elements are plotted. 
%  
% inputs : dim ......... dimension of the space 
%          M ........... number of frame elements
%
% output:  D ......... synthesis matrix of frames of dimension dim x M
%
% usage:  D = RandFrame(dim,M)
%
% test:   M = 5;
%         dim = 3;
%         D = RandFrame(dim,M);
%
% date: 27/06/2006 
%
% Author:  XXL .. Peter Balazs, contact: a8927259@unet.univie.ac.at
%
% Literature : [Xxl] P. Balazs; Frames, Finite Dimensionality and
%               Algorithms; in preparation (2006)
%
% See also: ApprFramMult.m
%
function D = RandFrame(dim,M)
D = zeros(dim,M);
while rank(D) ~= dim
    D = (rand(dim,M)-0.5)*2;
end;
sD = svd(D);
A = min(sD)^2;
B = max(sD)^2;
disp(sprintf('Created a frame with lower bound A = %g and upper bound B = %g',A,B));

if dim == 2
    D2 = D(1,:)+i*D(2,:);
	compass(D2);
elseif dim == 3
    Plot3DFrame(D);
    axis([-1 1 -1 1 -1 1]);
end
